==> open-cluster-management-operator-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/ExternalDNSGCPConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluentImpl;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExternalDNSGCPConfigFluentImpl<A extends ExternalDNSGCPConfigFluent<A>> extends BaseFluent<A> implements ExternalDNSGCPConfigFluent<A>{
  public ExternalDNSGCPConfigFluentImpl() {
  }
  public ExternalDNSGCPConfigFluentImpl(ExternalDNSGCPConfig instance) {
    this.withCredentials(instance.getCredentials()); 
  }
  private LocalObjectReferenceBuilder credentials;
  
  /**
   * This method has been deprecated, please use method buildCredentials instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getCredentials() {
    return this.credentials!=null ?this.credentials.build():null;
  }
  public LocalObjectReference buildCredentials() {
    return this.credentials!=null ?this.credentials.build():null;
  }
  public A withCredentials(LocalObjectReference credentials) {
    _visitables.get("credentials").remove(this.credentials);
    if (credentials!=null){ this.credentials= new LocalObjectReferenceBuilder(credentials); _visitables.get("credentials").add(this.credentials);} else { this.credentials = null; _visitables.get("credentials").remove(this.credentials); } return (A) this;
  }
  public Boolean hasCredentials() {
    return this.credentials != null;
  }
  public A withNewCredentials(String name) {
    return (A)withCredentials(new LocalObjectReference(name));
  }
  public ExternalDNSGCPConfigFluent.CredentialsNested<A> withNewCredentials() {
    return new ExternalDNSGCPConfigFluentImpl.CredentialsNestedImpl();
  }
  public ExternalDNSGCPConfigFluent.CredentialsNested<A> withNewCredentialsLike(LocalObjectReference item) {
    return new ExternalDNSGCPConfigFluentImpl.CredentialsNestedImpl(item);
  }
  public ExternalDNSGCPConfigFluent.CredentialsNested<A> editCredentials() {
    return withNewCredentialsLike(getCredentials());
  }
  public ExternalDNSGCPConfigFluent.CredentialsNested<A> editOrNewCredentials() {
    return withNewCredentialsLike(getCredentials() != null ? getCredentials(): new LocalObjectReferenceBuilder().build());
  }
  public ExternalDNSGCPConfigFluent.CredentialsNested<A> editOrNewCredentialsLike(LocalObjectReference item) {
    return withNewCredentialsLike(getCredentials() != null ? getCredentials(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExternalDNSGCPConfigFluentImpl that = (ExternalDNSGCPConfigFluentImpl) o;
    if (credentials != null ? !credentials.equals(that.credentials) :that.credentials != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(credentials,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (credentials != null) { sb.append("credentials:"); sb.append(credentials); }
    sb.append("}");
    return sb.toString();
  }
  class CredentialsNestedImpl<N> extends LocalObjectReferenceFluentImpl<ExternalDNSGCPConfigFluent.CredentialsNested<N>> implements ExternalDNSGCPConfigFluent.CredentialsNested<N>,Nested<N>{
    CredentialsNestedImpl(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    CredentialsNestedImpl() {
      this.builder = new LocalObjectReferenceBuilder(this);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) ExternalDNSGCPConfigFluentImpl.this.withCredentials(builder.build());
    }
    public N endCredentials() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/ExternalDNSGCPConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluentImpl;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExternalDNSGCPConfigFluentImpl<A extends ExternalDNSGCPConfigFluent<A>> extends BaseFluent<A> implements ExternalDNSGCPConfigFluent<A>{
  public ExternalDNSGCPConfigFluentImpl() {
  }
  public ExternalDNSGCPConfigFluentImpl(ExternalDNSGCPConfig instance) {
    if (instance != null) {
      this.withCredentials(instance.getCredentials());
    }
  }
  private LocalObjectReferenceBuilder credentials;
  
  /**
   * This method has been deprecated, please use method buildCredentials instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getCredentials() {
    return this.credentials!=null ?this.credentials.build():null;
  }
  public LocalObjectReference buildCredentials() {
    return this.credentials!=null ?this.credentials.build():null;
  }
  public A withCredentials(LocalObjectReference credentials) {
    _visitables.get("credentials").remove(this.credentials);
    if (credentials!=null){ this.credentials= new LocalObjectReferenceBuilder(credentials); _visitables.get("credentials").add(this.credentials);} else { this.credentials = null; _visitables.get("credentials").remove(this.credentials); } return (A) this;
  }
  public Boolean hasCredentials() {
    return this.credentials != null;
  }
  public A withNewCredentials(String name) {
    return (A)withCredentials(new LocalObjectReference(name));
  }
  public ExternalDNSGCPConfigFluentImpl.CredentialsNested<A> withNewCredentials() {
    return new ExternalDNSGCPConfigFluentImpl.CredentialsNestedImpl();
  }
  public ExternalDNSGCPConfigFluentImpl.CredentialsNested<A> withNewCredentialsLike(LocalObjectReference item) {
    return new ExternalDNSGCPConfigFluentImpl.CredentialsNestedImpl(item);
  }
  public ExternalDNSGCPConfigFluentImpl.CredentialsNested<A> editCredentials() {
    return withNewCredentialsLike(getCredentials());
  }
  public ExternalDNSGCPConfigFluentImpl.CredentialsNested<A> editOrNewCredentials() {
    return withNewCredentialsLike(getCredentials() != null ? getCredentials(): new LocalObjectReferenceBuilder().build());
  }
  public ExternalDNSGCPConfigFluentImpl.CredentialsNested<A> editOrNewCredentialsLike(LocalObjectReference item) {
    return withNewCredentialsLike(getCredentials() != null ? getCredentials(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalDNSGCPConfigFluentImpl that = (ExternalDNSGCPConfigFluentImpl) o;
    if (!java.util.Objects.equals(credentials, that.credentials)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(credentials,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (credentials != null) { sb.append("credentials:"); sb.append(credentials); }
    sb.append("}");
    return sb.toString();
  }
  class CredentialsNestedImpl<N> extends LocalObjectReferenceFluentImpl<ExternalDNSGCPConfigFluentImpl.CredentialsNested<N>> implements ExternalDNSGCPConfigFluentImpl.CredentialsNested<N>,Nested<N>{
    CredentialsNestedImpl(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    CredentialsNestedImpl() {
      this.builder = new LocalObjectReferenceBuilder(this);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) ExternalDNSGCPConfigFluentImpl.this.withCredentials(builder.build());
    }
    public N endCredentials() {
      return and();
    }
    
  }
  
}
